# MEDDOPROF Silver Standard

This repository contains the MEDDOPROF Silver Standard, a collection of clinical case reports of multiple specialties that have been automatically annotated with occupations, working statuses and activities using named entity recognition models trained on the [MEDDOPROF corpus](https://temu.bsc.es/meddoprof/). MEDDOPROF and this Silver Standard have been created by the Barcelona Supercomputing Center's NLP for Biomedical Information Analysis.

## About MEDDOPROF
MEDDOPROF is a corpus and shared task focused on the detection and normalization of occupations and related information such as working statuses and non-paid activities in clinical texts in Spanish. All mentions in the corpus have been normalized to [SNOMED CT](https://www.snomed.org/), with occupations also being normalized to the European Skills, Competences, and Occupations classification ([ESCO](https://esco.ec.europa.eu/en)).

MEDDOPLACE was released as part of the IberLEF 2021 workshop, which in turn was held within the SEPLN 2021 conference.

## Methods
To create this Silver Standard, we trained a NER model using the PharmaCoNER Tagger architecture ([GitHub](https://github.com/TeMU-BSC/PharmaCoNER-Tagger) | [Paper](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC6808625/)) and the MEDDOPROF corpus ([Web](https://temu.bsc.es/meddoprof/) | [Zenodo](https://zenodo.org/record/7116201)). The resulting model was used to predict occupations, working statuses and activities in a collection of over 13 thousand clinical case reports scrapped from open access publications. 

## Data Description
The Silver Standard includes 13,357 documents and a total of 5,568,844 tokens. The documents belong to over 10 different medical specialties, including occupational health, oncology, radiology, infectology, dermatology, psichiatry and more.

The corpus includes three different labels: PROFESION (occupation), SITUACION-LABORAL (working status) and ACTIVIDAD (activity/hobby). There is a total of 4,332 predictions (1,325 unique), with the most common label being PROFESION with 3,599 predictions (1,181 unique), followed by SITUACION-LABORAL with 682 (180 unique) and ACTIVIDAD with 51 (44 unique).

The annotations are presented in .ann format, which is the format used by the annotation tool [brat](https://brat.nlplab.org/). Each text file has an associated .ann file with the same name. Within .ann files, each line represents an annotation. For more information, please refer to this [brat standoff format explanation](https://brat.nlplab.org/standoff.html).

## Usage Notes
The data presented in this repository is the result of an automatic named entity recognition system and should not be used or interpreted as human-validated, Gold Standard data. That being said, you can use this Silver Standard for data analytics purposes, NLP research or knowledge graph creation, amongst other possible use cases. Detecting and studying occupational data can be useful for fields such as medicine, social care, human resources, legal NLP and even gender studies. Other NLP tasks such as anonymization might also benefit from this type of information.

## Citation
If you use this Silver Standard or any MEDDOPROF materials, please cite the task's overview paper:

``` 
Lima-López, Salvador, Eulàlia Farré-Maduell, Antonio Miranda-Escalada, Vicent Brivá-Iglesias, & Martin Krallinger. “NLP applied to occupational health: MEDDOPROF shared task at IberLEF 2021 on automatic recognition, classification and normalization of professions and occupations from medical texts.” Procesamiento del Lenguaje Natural [Online], 67 (2021): 243-256.
``` 

Alternatively, here is the citation in bibtex format:

```
@article{meddoprof,
title={NLP applied to occupational health: MEDDOPROF shared task at IberLEF 2021 on automatic recognition, classification and normalization of professions and occupations from medical texts},
author={Lima-López, Salvador and Farré-Maduell, Eulàlia and Miranda-Escalada, Antonio and Brivá-Iglesias, Vicent and Krallinger, Martin},
journal = {Procesamiento del Lenguaje Natural}, volume = {67}, year={2021}, issn = {1989-7553},
url = {http://journal.sepln.org/sepln/ojs/ojs/index.php/pln/article/view/6393}, pages = {243--256}
}
```

## License
<a rel="license" href="http://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/4.0/">Creative Commons Attribution 4.0 International License</a>.

## Contact
If you have any questions or suggestions, please contact us at:

- Salvador Lima-López (<salvador [dot] limalopez [at] gmail [dot] com>)
- Martin Krallinger (<krallinger [dot] martin [at] gmail [dot] com>)

## Acknowledgements
MEDDOPROF was promoted by the Spanish government's 2020 Proyectos de I+D+i RTI Tipo A (DESCIFRANDO EL PAPEL DE LAS PROFESIONES EN LA SALUD DE LOS PACIENTES A TRAVES DE LA MINERIA DE TEXTOS (PID2020-119266RA-I00)).